Content Producers
=================

This documentation is meant for the people who will create the surveys, curate the results, and decide how to display those results. If you want to really understand crowdsourcing and the kinds of things you can do with it, make your way through Objects and Options. If you just want to get going right now then the Examples are a fine place to start.

.. toctree::
   :maxdepth: 2

   options
   examples/index
   filters
   live
